@@ -18,6 +18,7 @@ def ndarray_from_numpy(arr: numpy.ndarray) -> Ndarray:
         dtype=dt,
         data=bytes(arr.data),
         strides=list(arr.strides),
+        order="CF"[arr.flags.f_contiguous],
     )
 
 
@@ -38,4 +39,12 @@ def ndarray_to_numpy(nda: Ndarray) -> numpy.ndarray:
             dtype=numpy.dtype(nda.dtype),
             strides=nda.strides,
         )
+    # The code that reads the bytes(arr.data) always results in C-ordered data.
+    # Passing `to the `np.ndarray(order=...)` call has no effect.
+    # This is where below workaround comes into play:
+    # It reshapes arrays that were originally in Fortran order.
+    # F-ordered arrays that were encoded with mcbackend < 0.2.4 default
+    # to `nda.order == ""` and there is nothing we can do for these.
+    if nda.order == "F":
+        arr = arr.T.reshape(arr.shape)
     return arr
